import { CoreAssistantMessage, CoreMessage, CoreToolMessage, CoreUserMessage, UserContent } from 'ai';
import { JSONSchema7 } from 'json-schema';
import { ZodSchema } from 'zod';
import 'dotenv/config';
import { MastraPrimitives } from '../action';
import { MastraBase } from '../base';
import { LLM } from '../llm';
import { GenerateReturn, ModelConfig, OutputType, StreamReturn } from '../llm/types';
import { CoreTool, ToolAction } from '../tools/types';
import { ToolsetsInput } from './types';
export declare class Agent<TTools extends Record<string, ToolAction<any, any, any, any>> = Record<string, ToolAction<any, any, any, any>>> extends MastraBase {
    #private;
    name: string;
    readonly llm: LLM;
    readonly instructions: string;
    readonly model: ModelConfig;
    tools: TTools;
    constructor(config: {
        name: string;
        instructions: string;
        model: ModelConfig;
        tools?: TTools;
        mastra?: MastraPrimitives;
    });
    __registerPrimitives(p: MastraPrimitives): void;
    /**
     * Set the concrete tools for the agent
     * @param tools
     */
    __setTools(tools: TTools): void;
    generateTitleFromUserMessage({ message }: {
        message: CoreUserMessage;
    }): Promise<string>;
    getMostRecentUserMessage(messages: Array<CoreMessage>): CoreUserMessage | undefined;
    genTitle(userMessage: CoreUserMessage | undefined): Promise<string>;
    saveMemory({ threadId, resourceid, userMessages, }: {
        resourceid: string;
        threadId?: string;
        userMessages: CoreMessage[];
        time?: Date;
        keyword?: string;
    }): Promise<{
        threadId: string;
        messages: CoreMessage[];
    }>;
    saveResponse({ result, threadId }: {
        result: Record<string, any>;
        threadId: string;
    }): Promise<void>;
    sanitizeResponseMessages(messages: Array<CoreToolMessage | CoreAssistantMessage>): Array<CoreToolMessage | CoreAssistantMessage>;
    convertTools({ toolsets, threadId, runId, }: {
        toolsets?: ToolsetsInput;
        threadId?: string;
        runId?: string;
    }): Record<string, CoreTool>;
    preExecute({ resourceid, runId, threadId, messages, }: {
        runId?: string;
        threadId?: string;
        messages: CoreMessage[];
        resourceid: string;
    }): Promise<{
        coreMessages: CoreMessage[];
        threadIdToUse: string;
    }>;
    __primitive({ messages, context, threadId, resourceid, runId, toolsets, }: {
        toolsets?: ToolsetsInput;
        resourceid?: string;
        threadId?: string;
        context?: CoreMessage[];
        runId?: string;
        messages: UserContent[];
    }): {
        before: () => Promise<{
            messageObjects: CoreMessage[];
            convertedTools: Record<string, CoreTool> | undefined;
            threadId: string;
        }>;
        after: ({ result, threadId }: {
            result: Record<string, any>;
            threadId: string;
        }) => Promise<void>;
    };
    generate<Z extends ZodSchema | JSONSchema7 | undefined = undefined>(messages: string | string[] | CoreMessage[], { context, threadId: threadIdInFn, resourceid, maxSteps, onStepFinish, runId, toolsets, output, }?: {
        toolsets?: ToolsetsInput;
        resourceid?: string;
        context?: CoreMessage[];
        threadId?: string;
        runId?: string;
        onStepFinish?: (step: string) => void;
        maxSteps?: number;
        output?: OutputType | Z;
    }): Promise<GenerateReturn<Z>>;
    stream<Z extends ZodSchema | JSONSchema7 | undefined = undefined>(messages: string | string[] | CoreMessage[], { context, threadId: threadIdInFn, resourceid, maxSteps, onFinish, onStepFinish, runId, toolsets, output, }?: {
        toolsets?: ToolsetsInput;
        resourceid?: string;
        context?: CoreMessage[];
        threadId?: string;
        runId?: string;
        onFinish?: (result: string) => Promise<void> | void;
        onStepFinish?: (step: string) => void;
        maxSteps?: number;
        output?: OutputType | Z;
    }): Promise<StreamReturn<Z>>;
}
//# sourceMappingURL=index.d.ts.map